pub struct KeyRotationStatement {
pub purpose: String,
pub domain: String,
pub from: String,
pub to: String,
pub effective_serial: u64,
pub retired_at_epoch_ms: u64,
}Expand description
Statement signed by an old domain key to authorize its successor.
Fields
purpose: Stringdomain: Stringfrom: Stringto: Stringeffective_serial: u64retired_at_epoch_ms: u64Trait Implementations
Sourceimpl Clone for KeyRotationStatement
impl Clone for KeyRotationStatement
Sourcefn clone(&self) -> KeyRotationStatement
fn clone(&self) -> KeyRotationStatement
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for KeyRotationStatement
impl Debug for KeyRotationStatement
Sourceimpl<'de> Deserialize<'de> for KeyRotationStatement
impl<'de> Deserialize<'de> for KeyRotationStatement
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for KeyRotationStatement
Sourceimpl PartialEq for KeyRotationStatement
impl PartialEq for KeyRotationStatement
Sourcefn eq(&self, other: &KeyRotationStatement) -> bool
fn eq(&self, other: &KeyRotationStatement) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for KeyRotationStatement
impl Serialize for KeyRotationStatement
impl StructuralPartialEq for KeyRotationStatement