pub struct TasteVerdictRecord {
pub verdict: TasteVerdict,
pub notes: Option<String>,
pub tasted_at_epoch_ms: u64,
}Expand description
A lightweight local taste verdict record for client-side caching.
Unlike the full Taste manifest (which is cryptographically signed and
content-addressed), this struct is for clients to persist their own taste
results locally — e.g. after an LLM safety review or manual inspection.
use substrate::TasteVerdictRecord;
use substrate::TasteVerdict;
let record = TasteVerdictRecord::new(TasteVerdict::Safe, Some("Reviewed, looks good"));
let json = serde_json::to_string_pretty(&record).unwrap();
let parsed: TasteVerdictRecord = serde_json::from_str(&json).unwrap();
assert_eq!(parsed.verdict, TasteVerdict::Safe);Fields
verdict: TasteVerdictnotes: Option<String>tasted_at_epoch_ms: u64Implementations
Sourceimpl TasteVerdictRecord
impl TasteVerdictRecord
Sourcepub fn new(verdict: TasteVerdict, notes: Option<&str>) -> Self
pub fn new(verdict: TasteVerdict, notes: Option<&str>) -> Self
Create a new verdict record stamped with the current time.
Sourcepub fn with_timestamp(
verdict: TasteVerdict,
notes: Option<&str>,
epoch_ms: u64,
) -> Self
pub fn with_timestamp( verdict: TasteVerdict, notes: Option<&str>, epoch_ms: u64, ) -> Self
Create a verdict record with an explicit timestamp.
Sourcepub fn allows_use(&self) -> bool
pub fn allows_use(&self) -> bool
Whether this verdict allows the spore to be used (i.e. not toxic).
Sourcepub fn gate_action_for(&self, operation: GateOperation) -> GateAction
pub fn gate_action_for(&self, operation: GateOperation) -> GateAction
Gate action for a given operation based on this verdict.