Module tree

Module tree 

Tree hashing for spores.

Re-exports

pub use blob_tree_blake3_nfc::compute_hash_from_entries;
pub use blob_tree_blake3_nfc::TreeEntry;
pub use walk::flatten_entries;
pub use walk::max_mtime;
pub use walk::should_exclude;
pub use walk::walk_dir;
pub use walk::DirEntry;
pub use walk::DirReader;

Modules

blob_tree_blake3_nfc
blob_tree_blake3_nfc tree hashing algorithm.
walk
Directory traversal with filtering for tree hashing, archive packing, and mtime computation.

Functions

compute_tree_hash_and_size_from_entries
Compute tree hash and total uncompressed source size in bytes.
compute_tree_hash_from_entries