pub struct CmnEntry {
pub schema: String,
pub protocol_versions: Vec<String>,
pub capsules: Vec<CmnCapsuleEntry>,
pub capsule_signature: String,
}Expand description
CMN Entry - the cmn.json file at /.well-known/cmn.json
Contains an array of capsules, each with a URI, public key, and typed endpoints for resolving all resource types.
Fields
schema: Stringprotocol_versions: Vec<String>capsules: Vec<CmnCapsuleEntry>capsule_signature: StringImplementations
Sourceimpl CmnEntry
impl CmnEntry
pub fn new(capsules: Vec<CmnCapsuleEntry>) -> Self
pub fn primary_capsule(&self) -> Result<&CmnCapsuleEntry>
pub fn uri(&self) -> Result<&str>
pub fn primary_key(&self) -> Result<&str>
pub fn primary_confirms_key(&self, key: &str) -> Result<bool>
pub fn effective_protocol_versions(&self) -> Vec<&str>
pub fn supports_protocol_version(&self, version: &str) -> bool
pub fn verify_signature(&self, host_key: &str) -> Result<()>